@@ -18,6 +18,10 @@ describe 'oslo::cache' do
         is_expected.to contain_keystone_config('cache/memcache_servers').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/enable_socket_keepalive').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/socket_keepalive_idle').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/socket_keepalive_interval').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/socket_keepalive_count').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('<SERVICE DEFAULT>')
@@ -26,6 +30,12 @@ describe 'oslo::cache' do
         is_expected.to contain_keystone_config('cache/tls_certfile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/tls_keyfile').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('cache/tls_allowed_ciphers').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/enable_retry_client').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/retry_attempts').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/retry_delay').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/hashclient_retry_attempts').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/hashclient_retry_delay').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('cache/dead_timeout').with_value('<SERVICE DEFAULT>')
       end
     end
 
@@ -42,6 +52,10 @@ describe 'oslo::cache' do
           :memcache_servers                     => ['host1:11211', 'host2:11211','[fd12:3456:789a:1::1]:11211'],
           :memcache_dead_retry                  => '300',
           :memcache_socket_timeout              => '3.0',
+          :enable_socket_keepalive              => false,
+          :socket_keepalive_idle                => 1,
+          :socket_keepalive_interval            => 1,
+          :socket_keepalive_count               => 1,
           :memcache_pool_maxsize                => '10',
           :memcache_pool_unused_timeout         => '60',
           :memcache_pool_connection_get_timeout => '10',
@@ -50,6 +64,12 @@ describe 'oslo::cache' do
           :tls_certfile                         => nil,
           :tls_keyfile                          => nil,
           :tls_allowed_ciphers                  => nil,
+          :enable_retry_client                  => false,
+          :retry_attempts                       => 2,
+          :retry_delay                          => 0,
+          :hashclient_retry_attempts            => 2,
+          :hashclient_retry_delay               => 1,
+          :dead_timeout                         => 60,
         }
       end
 
@@ -61,9 +81,13 @@ describe 'oslo::cache' do
         is_expected.to contain_keystone_config('cache/proxies').with_value('proxy1,proxy2')
         is_expected.to contain_keystone_config('cache/enabled').with_value('true')
         is_expected.to contain_keystone_config('cache/debug_cache_backend').with_value('true')
-        is_expected.to contain_keystone_config('cache/memcache_servers').with_value('host1:11211,host2:11211,inet6:[fd12:3456:789a:1::1]:11211')
+        is_expected.to contain_keystone_config('cache/memcache_servers').with_value('host1:11211,host2:11211,[fd12:3456:789a:1::1]:11211')
         is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('300')
         is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('3.0')
+        is_expected.to contain_keystone_config('cache/enable_socket_keepalive').with_value('false')
+        is_expected.to contain_keystone_config('cache/socket_keepalive_idle').with_value('1')
+        is_expected.to contain_keystone_config('cache/socket_keepalive_interval').with_value('1')
+        is_expected.to contain_keystone_config('cache/socket_keepalive_count').with_value('1')
         is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('10')
         is_expected.to contain_keystone_config('cache/memcache_pool_unused_timeout').with_value('60')
         is_expected.to contain_keystone_config('cache/memcache_pool_connection_get_timeout').with_value('10')
@@ -72,6 +96,12 @@ describe 'oslo::cache' do
         is_expected.to contain_keystone_config('cache/tls_certfile').with_value('nil')
         is_expected.to contain_keystone_config('cache/tls_keyfile').with_value('nil')
         is_expected.to contain_keystone_config('cache/tls_allowed_ciphers').with_value('nil')
+        is_expected.to contain_keystone_config('cache/enable_retry_client').with_value('false')
+        is_expected.to contain_keystone_config('cache/retry_attempts').with_value('2')
+        is_expected.to contain_keystone_config('cache/retry_delay').with_value('0')
+        is_expected.to contain_keystone_config('cache/hashclient_retry_attempts').with_value('2')
+        is_expected.to contain_keystone_config('cache/hashclient_retry_delay').with_value('1')
+        is_expected.to contain_keystone_config('cache/dead_timeout').with_value('60')
       end
     end
 
@@ -123,12 +153,14 @@ describe 'oslo::cache' do
     context 'with memcache backend' do
       let :params do
         {
-          :backend => 'dogpile.cache.memcache',
+          :backend          => 'dogpile.cache.memcache',
+          :memcache_servers => ['host1:11211', 'host2:11211','[fd12:3456:789a:1::1]:11211'],
         }
       end
 
       it 'configures cache backend' do
         is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcache')
+        is_expected.to contain_keystone_config('cache/memcache_servers').with_value('host1:11211,host2:11211,inet6:[fd12:3456:789a:1::1]:11211')
         is_expected.to contain_package('python-memcache').with(
           :ensure => 'installed',
           :name   => platform_params[:python_memcache_package_name],
